<?php

namespace App\Entity;

use ApiPlatform\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Metadata\ApiFilter;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\GraphQl\QueryCollection;
use App\Repository\SaleRepository;
use App\Resolver\SeriesResolver;
use App\Resolver\SeriesRegionDistribResolver;
use App\State\SeriesProvider;
use App\State\SeriesRegionDistribProvider;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

#[ApiResource(operations: [
    new GetCollection(uriTemplate: '/sales/series')
], graphQlOperations: [
    new QueryCollection(
        name: 'series',
        resolver: SeriesResolver::class,
        read: false,
    )
], provider: SeriesProvider::class, paginationEnabled: false)]
#[ApiResource(operations: [
    new GetCollection(uriTemplate: '/sales/seriesRegionDistrib')
], graphQlOperations: [
    new QueryCollection(
        name: 'series',
        resolver: SeriesRegionDistribResolver::class,
        read: false,
    )
], provider: SeriesRegionDistribProvider::class, paginationEnabled: false)]
#[ApiFilter(DateFilter::class, properties: ['date'])]
#[ORM\Entity(repositoryClass: SaleRepository::class)]
class Sale
{
    #[ORM\Id]
    #[ORM\Column(type: 'integer')]
    #[ORM\GeneratedValue]
    private ?int $id = null;

    #[ORM\Column]
    public string $type = '';

    #[ORM\Column(type: 'integer')]
    #[Assert\Range(min: 0)]
    public int $value = 0;

    #[ORM\Column(type: 'integer')]
    #[Assert\Range(min: 0)]
    public int $code_departement = 0;

    #[ORM\Column]
    public ?string $region = '';

    #[ORM\Column(type: 'integer')]
    #[Assert\Range(min: 0)]
    public int $surface = 0;
    
    #[ORM\Column]
    #[Assert\NotNull]
    public ?\DateTimeImmutable $date = null;

    public function getId(): ?int
    {
        return $this->id;
    }
}
